from setuptools import setup

setup(name='distributions_Gauss',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_Gauss'],
      author= 'LOGESWARAN SIVAKUMAR',
      zip_safe=False)
